%programa inver.m

%Este programa resuelve el modelo con dos bienes e inversin que

%requiere la participacin de los bienes transables y no transables

% inf

%max sum beta^t (c(t)^(1-eta)-1)/(1-eta)

% t=0

% s.a. b(t+1)+cT(t)+xT(t)<=aT*kT^alphaT+(1+r)*b(t)

% cN(t)+xN(t)<=aN*kN(t)^alphaN

% iT(t)+iN(t)<=GxT(t)^gamma*xN(t)^(1-gamma)

% kT(t+1)<=iT(t)+(1-delta)*kT(t)

% kN(t+1)<=iN(t)+(1-delta)*kN(t)

% k(0) dado, b(0) dado

clear

%Definicin de los parmetros del modelo

aT = 0.96612775*34.3541;

aN = 0.90461754*35.4459;

alphaT = 0.3071665;

alphaN = 0.35370848;

gamma = 0.39681632;

G = 1.95756169;

rho = -1;

theta = -1;

epsilon = (0.852600116^(1/(1-rho)))/(1+0.852600116^(1/(1-rho)));

delta = 0.0576;

beta = 0.9463;

r = 1/beta-1;

bss = 0;

%Definicin de parmetros del programa

maxit = 1000;

crit = 1e-8;

T = 40;

%Llamada a secant.m para computar el estado estacionario

x0 = [896; 981];

param = [aT aN alphaT alphaN gamma G rho theta epsilon delta beta bss];

sol = secant('sscpo', x0, param, crit, maxit);

%Resultados del estado estacionario

kTss = sol(1);

kNss = sol(2);

rss = 1/beta-1;

kss = kTss+kNss;

mpkTss = aT*alphaT*kTss^(alphaT-1);

mpkNss = aN*alphaN*kNss^(alphaN-1);

pNss = mpkTss/mpkNss;

ratxss = gamma*pNss/(1-gamma);

xNss = delta*kss/(G*ratxss^gamma);

xTss = ratxss*xNss;

qss = ratxss^(1-gamma)/(G*gamma);

yTss = aT*kTss^alphaT;

yNss = aN*kNss^alphaN;

cNss = yNss-xNss;

cTss = ((1-epsilon)/(epsilon*pNss))^(1/(rho-1))*cNss;

%Estado estacionario computado

%Construccin de la semilla

kTguess = kTss*ones(size(1:T-1))';

kNguess = kNss*ones(size(1:T-1))';

bguess = bss*ones(size(1:T-1))';

Mguess = [kTguess kNguess bguess];

guess = [kTss kNss bss];

for t=2:T-1

c = Mguess(t,:);

guess = [guess c];

end

guess(3*t+1) = kTss;

guess(3*t+2) = kNss;

%LLamada a secant.m para computar la dinmica

kT0 = kTss*0.8;

kN0 = kNss*0.8;

param = [aT aN alphaT alphaN gamma G rho theta epsilon delta beta bss T kT0 kN0];

sol = secant('dincpo', guess', param, crit, maxit);

for t=1:T

kT(t) = sol(3*t-2);

kN(t) = sol(3*t-1);

end

for t=1:T-1

b(t) = sol(3*t);

end

%Reconstruccin de las trayectorias de equilibrio

mpkT(1) = aT*alphaT*kT(1)^(alphaT-1);

mpkN(1) = aN*alphaN*kN(1)^(alphaN-1);

pN(1) = mpkT(1)/mpkN(1);

ratx(1) = gamma*pN(1)/(1-gamma);

xN(1) = (kT(2)+kN(2)-(1-delta)*(kT(1)+kN(1)))/(G*ratx(1)^gamma);

xT(1) = ratx(1)*xN(1);

q(2) = ratx(1)^(1-gamma)/(G*gamma);

yT(1) = aT*kT(1)^alphaT;

yN(1) = aN*kN(1)^alphaN;

cN(1) = yN(1)-xN(1);

cT(1) = ((1-epsilon)/(epsilon*pN(1)))^(1/(rho-1))*cN(1);

u(1) = theta*(epsilon*cT(1)^rho+(1-epsilon)*cN(1)^rho)^(theta/rho-1);

for t=2:T-1

mpkT(t) = aT*alphaT*kT(t)^(alphaT-1);

mpkN(t) = aN*alphaN*kN(t)^(alphaN-1);

pN(t) = mpkT(t)/mpkN(t);

ratx(t) = gamma*pN(t)/(1-gamma);

xN(t) = (kT(t+1)+kN(t+1)-(1-delta)*(kT(t)+kN(t)))/(G*ratx(t)^gamma);

xT(t) = ratx(t)*xN(t);

q(t+1) = ratx(t)^(1-gamma)/(G*gamma);

yT(t) = aT*kT(t)^alphaT;

yN(t) = aN*kN(t)^alphaN;

cN(t) = yN(t)-xN(t);

cT(t) = ((1-epsilon)/(epsilon*pN(t)))^(1/(rho-1))*cN(t);

u(t) = theta*(epsilon*cT(t)^rho+(1-epsilon)*cN(t)^rho)^(theta/rho-1);

end

yT0 = aT*kT0^alphaT;

yT = [yT0 aT*kT(1:T).^alphaT];

yN0 = aN*kN0^alphaN;

yN = [yN0 aN*kN(1:T).^alphaN];

b0 = 0;

bT = [b0 b];

ca = [0 bT(2:T)-bT(1:T-1)];

td0 = 0;

td1 = aT*kT(1:T-1).^alphaT-cT(1:T-1)-xT(1:T-1);

td = [td0 td1];

figure

plot(yT)

title('Producto')

figure

plot(kT)

title('Capital')

figure

plot(ca)

title('Cuenta corriente')

figure

plot(td)

title('Dficit comercial')